@@ -1,13 +1,13 @@
 package Sys::Info::Driver::Linux;
 use strict;
-use warnings;
 use vars qw( $VERSION @ISA @EXPORT );
-use base qw( Exporter );
+use Exporter ();
 
-$VERSION = '0.75_01';
+$VERSION = '0.70';
+@ISA     = qw( Exporter );
 @EXPORT  = qw( proc );
 
-use constant proc => { ## no critic (NamingConventions::Capitalization)
+use constant proc => {
     loadavg  => '/proc/loadavg', # average cpu load
     cpuinfo  => '/proc/cpuinfo', # cpu information
     uptime   => '/proc/uptime',  # uptime file
@@ -34,13 +34,6 @@ Sys::Info::Driver::Linux - Linux driver for Sys::Info
 
 =head1 DESCRIPTION
 
-This document describes version C<0.75_01> of C<Sys::Info::Driver::Linux>
-released on C<10 April 2010>.
-
-B<WARNING>: This version of the module is part of a
-developer (beta) release of the distribution and it is
-not suitable for production use.
-
 This is the main module in the C<Linux> driver collection.
 
 =head1 METHODS
@@ -55,11 +48,11 @@ Automatically exported. Includes paths to several files.
 
 =head1 AUTHOR
 
-Burak Gursoy <burak@cpan.org>.
+Burak Grsoy, E<lt>burakE<64>cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright 2006 - 2010 Burak Gursoy. All rights reserved.
+Copyright 2006-2009 Burak Grsoy. All rights reserved.
 
 =head1 LICENSE
 
