@@ -1,9 +1,8 @@
 package Sys::Info::Driver::Linux::Device;
 use strict;
-use warnings;
 use vars qw( $VERSION );
 
-$VERSION = '0.75_01';
+$VERSION = '0.70';
 
 1;
 
@@ -19,13 +18,6 @@ Sys::Info::Driver::Linux::Device - Base class for Linux device drivers
 
 =head1 DESCRIPTION
 
-This document describes version C<0.75_01> of C<Sys::Info::Driver::Linux::Device>
-released on C<10 April 2010>.
-
-B<WARNING>: This version of the module is part of a
-developer (beta) release of the distribution and it is
-not suitable for production use.
-
 Base class for Linux device drivers.
 
 =head1 METHODS
@@ -34,11 +26,11 @@ None.
 
 =head1 AUTHOR
 
-Burak Gursoy <burak@cpan.org>.
+Burak Grsoy, E<lt>burakE<64>cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright 2006 - 2010 Burak Gursoy. All rights reserved.
+Copyright 2006-2009 Burak Grsoy. All rights reserved.
 
 =head1 LICENSE
 
